<?php
/**
 * Template part for displaying posts
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package guj
 */

?>

<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
    <header class="entry-header">
            <?php guj_the_category_list () ;?>
            <?php
            if ( is_singular() ) :
                    the_title( '<h1 class="entry-title">', '</h1>' );
            else :
                    the_title( '<h2 class="entry-title"><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">', '</a></h2>' );
            endif;

            $blog_content_layout = guj_get_option('blog_layout_options');

            if ( 'pull-left' === $blog_content_layout || 'pull-right' === $blog_content_layout ) :
                    ?>
                    <div class="entry-meta">
                            <?php
                            guj_posted_by();
                            guj_posted_on();
                            ?>
                    </div><!-- .entry-meta -->
            <?php endif; ?>
    </header><!-- .entry-header -->

	<?php
		if (has_post_thumbnail()) { ?>
			<figure class="featured-image full-bleed">
				<?php the_post_thumbnail('guj-full-bleed') ;?>
			</figure> <!--.featured-image .full-bleed-->
	<?php	} ?>

	<section class="post-content">

		<?php if ( 'no-sidebar' === $blog_content_layout ) : ?>
			<div class="post-content__wrap">
				<div class="entry-meta">
					<?php
					guj_posted_by();
					guj_posted_on();
					?>
				</div><!-- .entry-meta -->
				<div class="post-content__body">
			<?php endif; ?>

			<div class="entry-content">
				<?php
				the_content( sprintf(
					wp_kses(
						/* translators: %s: Name of current post. Only visible to screen readers */
						__( 'Continue reading<span class="screen-reader-text"> "%s"</span>', 'guj' ),
						array(
							'span' => array(
								'class' => array(),
							),
						)
					),
					get_the_title()
				) );

				wp_link_pages( array(
					'before' => '<div class="page-links">' . esc_html__( 'Pages:', 'guj' ),
					'after'  => '</div>',
				) );
				?>
			</div><!-- .entry-content -->

			<footer class="entry-footer">
				<?php guj_entry_footer(); ?>
			</footer><!-- .entry-footer -->

			<?php if ( 'no-sidebar' === $blog_content_layout ) : ?>
			</div> <!--.post-content__body-->
	</div> <!--.post-content__wrap-->
<?php endif; ?>
		<?php
		guj_post_navigation ();

		// If comments are open or we have at least one comment, load up the comment template.
		if ( comments_open() || get_comments_number() ) :
			comments_template();
		endif;
		?>

	</section> <!--.post-content-->
	<?php 
        if ( 'pull-left' === $blog_content_layout || 'pull-right' === $blog_content_layout ) {
        get_sidebar() ;
        }
        ?>
</article><!-- #post-<?php the_ID(); ?> -->
